@@ -1,5 +1,5 @@
 package Cpanel::JSON::XS;
-our $VERSION = '4.08';
+our $VERSION = '4.09';
 our $XS_VERSION = $VERSION;
 # $VERSION = eval $VERSION;
 
@@ -645,11 +645,12 @@ L</allow_barekey> option.
 
     { foo:"bar" }
 
-=item * duplicate keys
+=item * allow_dupkeys
 
-With relaxed decoding of duplicate keys does not error and are silently accepted.
+Allow decoding of duplicate keys in hashes. By default duplicate keys are forbidden.
 See L<http://seriot.ch/parsing_json.php#24>:
 RFC 7159 section 4: "The names within an object should be unique."
+See the L</allow_dupkeys> option.
 
 =back
 
@@ -824,6 +825,22 @@ This option does not affect C<decode> in any way.
 This option is special to this module, it is not supported by other
 encoders.  So it is not recommended to use it.
 
+=item $json = $json->allow_dupkeys ([$enable])
+
+=item $enabled = $json->get_allow_dupkeys
+
+If C<$enable> is true (or missing), then the C<decode> method will not
+die when it encounters duplicate keys in a hash.
+C<allow_dupkeys> is also enabled in the C<relaxed> mode.
+
+The JSON spec allows duplicate name in objects but recommends to
+disable it, however with Perl hashes they are impossible, parsing
+JSON in Perl silently ignores duplicate names, using the last value
+found.
+
+See L<http://seriot.ch/parsing_json.php#24>:
+RFC 7159 section 4: "The names within an object should be unique."
+
 =item $json = $json->allow_blessed ([$enable])
 
 =item $enabled = $json->get_allow_blessed
